==> fasc-openapi-java-sdk-5.2.6.2-sources.jar: com/fasc/open/api/v5_1/req/seal/GetSealFreeSignUrlReq.java <==
package com.fasc.open.api.v5_1.req.seal;

import com.fasc.open.api.bean.base.BaseReq;

import java.util.List;

/**
 * @Author： zfc
 * @Date: 2022/11/30
 */
public class GetSealFreeSignUrlReq extends BaseReq {
    private String openCorpId;
    private List<Long> sealIds;
    private String businessId;
    private String email;
    private String clientUserId;
    private String redirectUrl;
    private String expiresTime;

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public List<Long> getSealIds() {
        return sealIds;
    }

    public void setSealIds(List<Long> sealIds) {
        this.sealIds = sealIds;
    }

    public String getBusinessId() {
        return businessId;
    }

    public void setBusinessId(String businessId) {
        this.businessId = businessId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getClientUserId() {
        return clientUserId;
    }

    public void setClientUserId(String clientUserId) {
        this.clientUserId = clientUserId;
    }

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    public String getExpiresTime() {
        return expiresTime;
    }

    public void setExpiresTime(String expiresTime) {
        this.expiresTime = expiresTime;
    }
}

==> fasc-openapi-java-sdk-5.7.7.1103-sources.jar: com/fasc/open/api/v5_1/req/seal/GetSealFreeSignUrlReq.java <==
package com.fasc.open.api.v5_1.req.seal;

import com.fasc.open.api.bean.base.BaseReq;

import java.util.List;

/**
 * @Author： zfc
 * @Date: 2022/11/30
 */
public class GetSealFreeSignUrlReq extends BaseReq {
    private String openCorpId;
    private List<Long> sealIds;
    private String businessId;
    private String email;
    private String clientUserId;
    private String redirectUrl;
    private String redirectMiniAppUrl;
    private String expiresTime;

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public List<Long> getSealIds() {
        return sealIds;
    }

    public void setSealIds(List<Long> sealIds) {
        this.sealIds = sealIds;
    }

    public String getBusinessId() {
        return businessId;
    }

    public void setBusinessId(String businessId) {
        this.businessId = businessId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getClientUserId() {
        return clientUserId;
    }

    public void setClientUserId(String clientUserId) {
        this.clientUserId = clientUserId;
    }

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    public String getRedirectMiniAppUrl() {
        return redirectMiniAppUrl;
    }

    public void setRedirectMiniAppUrl(String redirectMiniAppUrl) {
        this.redirectMiniAppUrl = redirectMiniAppUrl;
    }

    public String getExpiresTime() {
        return expiresTime;
    }

    public void setExpiresTime(String expiresTime) {
        this.expiresTime = expiresTime;
    }
}
